# Trexit
Elegant directory visualization and content exploration tools

## Installation

```bash
pip install trexit
```

## Usage

Print directory tree:
```bash
trexit [path] [--ignore dir1 dir2 ...]
```

Save directory contents:
```bash
drexit [path] -o output.txt [--ignore dir1 dir2 ...]
```